Type Alias reef::types::NullifierProof
source · pub type NullifierProof<L> = <NullifierSet<L> as NullifierSet>::Proof;Expand description
A proof that a nullifier is spent or unspent, relative to a ledger L.
pub type NullifierProof<L> = <NullifierSet<L> as NullifierSet>::Proof;A proof that a nullifier is spent or unspent, relative to a ledger L.