Type Alias reef::types::NullifierSet
source · pub type NullifierSet<L> = <Transaction<L> as Transaction>::NullifierSet;Expand description
A set of spent nullifiers for a ledger L.
pub type NullifierSet<L> = <Transaction<L> as Transaction>::NullifierSet;A set of spent nullifiers for a ledger L.