Type Alias reef::types::Transaction
source · pub type Transaction<L> = <Block<L> as Block>::Transaction;Expand description
A transaction that can be applied to a ledger L.
pub type Transaction<L> = <Block<L> as Block>::Transaction;A transaction that can be applied to a ledger L.