Type Alias reef::types::TransactionHash
source · pub type TransactionHash<L> = <Transaction<L> as Transaction>::Hash;Expand description
A committing hash of a transaction that can be applied to a ledger L.
pub type TransactionHash<L> = <Transaction<L> as Transaction>::Hash;A committing hash of a transaction that can be applied to a ledger L.